#
# spec file for package python-gitdb
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-gitdb
Version:        4.0.11
Release:        1.5
Summary:        Git Object Database
License:        BSD-3-Clause
URL:            https://github.com/gitpython-developers/gitdb
Source:         https://files.pythonhosted.org/packages/source/g/gitdb/gitdb-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module smmap >= 3.0.1}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-smmap >= 3.0.1
Provides:       python-gitdb2 = %{version}
Obsoletes:      python-gitdb2 < %{version}
%python_subpackages

%description
GitDB is a pure-Python git object database

%prep
%setup -q -n gitdb-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Package requires its own git tree in order to pass tests
#%%python_exec setup.py test

%files %{python_files}
%license LICENSE
%doc AUTHORS
%{python_sitelib}/gitdb*

%changelog
* Mon Nov 27 2023 Dirk Müller <dmueller@suse.com>
- update to 4.0.11:
  * Use ZLIB_RUNTIME_VERSION if available
  * Add support for Python 3.12 and drop EOL 3.7
  * Fix mkdir race condition in LooseObjectDB.store
  * Don't cancel other jobs from the 3.12 job failing
  * Use actions/checkout feature to fetch all commits
  * Revert "Drop support for EOL Python 3.7"
  * Fix top-of-file license URLs here in gitdb too
  * No longer treat 3.12 as experimental on CI
  * Add __all__ to exc for linting
  * Have Dependabot update smmap submodule dependency
  * Bump gitdb/ext/smmap from `334ef84` to `f1ace75`
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Tue Dec  6 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v4.0.10:
  * improvements to the way external packages are imported.
* Tue Oct 26 2021 Dirk Müller <dmueller@suse.com>
- update to 4.0.9:
  * update signing key
  * fix Sphinx warnings
  * Support Python 3.7+
  * Allow smmap 5
* Tue May 18 2021 Dirk Müller <dmueller@suse.com>
- update to 4.0.7:
  * Fix exception causes in loose.py
  * Fix exception causes all over the codebase
  * Add Ram Rachum to AUTHORS
  * Update smmap upper bound in setup.py
* Tue Jun  2 2020 Dirk Mueller <dmueller@suse.com>
- update to 4.0.5:
  * Support for PyOxidizer
* Mon Mar 30 2020 Tomáš Chvátal <tchvatal@suse.com>
- Provide and obsolete deprecated gitdb2 module
* Mon Mar 30 2020 Tomáš Chvátal <tchvatal@suse.com>
- No need to version the setuptools dependency
* Mon Mar 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 4.0.2:
  * Updated to release as Pure Python Wheel rather than Universal Wheel (#62)
  * Switched back to the gitdb package name on PyPI and fixed the gitdb2 mirror package (#59)
  * Switched back to require smmap package and fixed version requirement to >= 3.0.1, < 4 (#59)
  * Updated smmap submodule
  * Changed force_bytes to use UTF-8 encoding by default (#49)
  * Removed Python 2 compatibility shims (#56)
* Tue Oct  8 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.0.6:
  * minor bugfixes only
* Mon Mar  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.0.5:
  * Just few formating fixes
* Sat Jul 21 2018 arun@gmx.de
- specfile:
  * be more specific in %%file section
- update to version 2.0.4:
  * Update version just to get a new release signed with valid key
* Wed Jan 17 2018 toddrme2178@gmail.com
- update to version 2.0.3
* Tue Aug 15 2017 daniel.molkentin@suse.com
- update to version 2.0.2
- converted to singlespec
- moved to separate package due to source package rename
* Tue May  5 2015 benoit.monin@gmx.fr
- update to version 0.6.4:
  * no upstream changelog
- additional changes from version 0.6.1:
  * Fixed possibly critical error, see
    https://github.com/gitpython-developers/GitPython/issues/220
- additional changes from version 0.6.0:
  * Added support got python 3.X
  * Removed all async dependencies and all *_async versions of
    methods with it.
- remove python-async: now unneeded
- set a minimum version for python-smmap: required by upstream
- define python_sitearch only for SLE11
* Thu Nov 24 2011 saschpe@suse.de
- Set license to SDPX style (BSD-3-Clause)
- Remove outdated %%clean section
- Use upstream tarball
* Wed Jul  6 2011 alexandre@exatati.com.br
- Initial package (0.5.4) for openSUSE.
